<?php

namespace Ep\Images;

use Psr\Container\ContainerInterface;

/**
 * Class ImageManagerFactory
 *
 * @package Ep\Images
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/image
 */
class ImageManagerFactory
{
    /**
     * @param ContainerInterface $container
     * @param string $requestedName
     * @param array|null $options
     *
     * @return object
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['images'] ?? [];

        $basePath = $config['base_path'] ?? '';

        if (empty($basePath)) {
            $basePath = getcwd() . '/images';
        }

        if (!file_exists($basePath)) {
            mkdir($basePath);
        }

        if (!is_dir($basePath)) {
            throw new \RuntimeException(sprintf("Putanja `%s` nije direktorij.", $basePath));
        }

        if (!is_writable($basePath)) {
            throw new \RuntimeException(sprintf("Aplikacija ne može pisati u direktorij `%s`.", $basePath));
        }

        return new ImageManager($basePath, $config['sprites']);
    }
}