<?php

namespace Ep\Images\Middleware;

use Ep\Images\ImageManager;
use Ep\Images\Sprite\SpriteMap;
use Ep\Middleware\BaseUrl;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Zend\Diactoros\Response\HtmlResponse;
use Zend\Diactoros\Response\JsonResponse;

/**
 * Class Manager
 *
 * @package Ep\Images\Middleware
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class Sprites implements MiddlewareInterface
{
    /** @var ImageManager */
    protected $images;

    /**
     * ImageManagerMiddleware constructor.
     *
     * @param ImageManager $images
     */
    public function __construct(ImageManager $images)
    {
        $this->images = $images;
    }

    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @throws \ImagickException
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        $baseUri = (string) $request->getAttribute(BaseUrl::BASE_URL);
        $path = $request->getUri()->getPath();
        $pieces = explode('/', substr($path, 1));

        $dimension = $pieces[0];
        list($width, $height) = explode('x', $dimension);

        $images = explode(',', $pieces[1]);
        $name = md5(json_encode($images));

        $spriteMap = new SpriteMap($name, $this->images->spriteConfig);
        $sprite = [];

        foreach ($images as $image) {
            list($x, $y, $index) = explode(' ', $spriteMap->render($image, $width, $height));
            $sprite[$image] = $index;
        }
        $spriteMap->flush();

        $data = [
            'url' => $baseUri . $spriteMap->getImageUrl($width, $height),
            'map' => $sprite
        ];

//        return new JsonResponse($data);
        return (new HtmlResponse($spriteMap->getData($width, $height)))->withHeader('Content-Type', 'image/png');
    }

}
