<?php
namespace EpTest\Images;

use Ep\Images\Image;
use Ep\Images\ImageManager;
use PHPUnit\Framework\TestCase;
use Symfony\Component\Filesystem\Filesystem;

/**
 * Class ImageManagerTest
 *
 * @package EpTest\Images
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/images
 */
class ImageManagerTest extends TestCase
{
    use ImagesAwareTrait;

    /** @var array */
    protected $addedImages = [];
    /** @var Filesystem */
    protected $fs;

    public function __construct(?string $name = null, array $data = [], string $dataName = '')
    {
        parent::__construct($name, $data, $dataName);
        $this->fs = new Filesystem();
    }


    protected function setUp()/* The :void return type declaration that should be here would cause a BC issue */
    {
        parent::setUp();
        $this->fs->mkdir(__DIR__ . '/serve');
    }

    protected function tearDown()/* The :void return type declaration that should be here would cause a BC issue */
    {
        parent::tearDown();
        $this->fs->remove(__DIR__ . '/serve');
    }

    public function testImageManagerCanSaveImage()
    {
        $container = $this->createContainer();
        /** @var ImageManager $manager */
        $manager = $container->get('image_manager');

        $src = __DIR__ . '/data/image.jpg';
        $dest = __DIR__ . '/serve/dir/test-image.jpg';

        $image = new Image();
        $image->loadFile(__DIR__ . '/data/image.jpg');
        $image->setPath('dir/test-image.jpg');

        $manager->saveImage($image);

        $this->assertFileExists($dest);
        $this->assertEquals(filesize($src), filesize($dest));
    }
}