<?php
namespace EpTest\Images;

use Ep\Images\Image;
use PHPUnit\Framework\TestCase;

/**
 * Class ImageTest
 *
 * @package EpTest\Images
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/images
 */
class ImageTest extends TestCase
{
    /**
     * @throws \ReflectionException
     */
    public function testCanDetectImageJpeg()
    {
        $image = new Image();
        $data = file_get_contents(__DIR__ . '/data/image.jpg');

        $imageClass = new \ReflectionClass($image);
        $property = $imageClass->getProperty('data');
        $property->setAccessible(true);
        $property->setValue($image, $data);

        $this->assertEquals('image/jpeg', $image->getType());
    }

    /**
     * @throws \ReflectionException
     */
    public function testCanDetectImagePng()
    {
        $image = new Image();
        $data = file_get_contents(__DIR__ . '/data/image.png');

        $imageClass = new \ReflectionClass($image);
        $property = $imageClass->getProperty('data');
        $property->setAccessible(true);
        $property->setValue($image, $data);

        $this->assertEquals('image/png', $image->getType());
    }

    /**
     * @expectedException \Ep\Images\Exception\InvalidImageTypeException
     *
     * @throws \ReflectionException
     */
    public function testWillThrowExceptionForInvalidImageType()
    {
        $image = new Image();
        $data = file_get_contents(__DIR__ . '/data/image.gif');

        $imageClass = new \ReflectionClass($image);
        $property = $imageClass->getProperty('data');
        $property->setAccessible(true);
        $property->setValue($image, $data);

        $image->getType();
    }
}